@@ -1,6 +1,9 @@
-from .browser import Browser
+import igv_notebook
 from urllib.parse import urlparse
 from os.path import basename
+from IPython import get_ipython
+from .navbar import show_navbar
+
 
 # Attempt to import nbtools, if it's not installed create a dummy decorator that does nothing
 try:
@@ -12,11 +15,12 @@ except ImportError:
         return decorator
 
 
-@build_ui(name="igv.js: Integrative Genomics Viewer",
+@build_ui(name="Integrative Genomics Viewer (IGV)",
           description="Use igv.js to embed an interactive genome visualization",
           logo="http://igv.org/web/img/favicon.ico",
           origin="+",
           run_label="Visualize",
+          color='#4a8797',
           parameter_groups=[
               {
                   "name": "Basic Parameters",
@@ -25,7 +29,8 @@ except ImportError:
               {
                   "name": "Advanced Parameters",
                   "parameters": ["track_format", "track_type"],
-                  "hidden": True
+                  "hidden": False,
+                  "advanced": True
               }
           ],
           parameters={
@@ -129,13 +134,17 @@ except ImportError:
               }
           })
 def igv_tool(genome, tracks=None, indices=None, track_format=None, track_type=None, locus=None):
+    # Create the navbar
+    show_navbar()
+
     # Create the genome browser and display it
-    browser = Browser({"genome": genome, "locus": locus})
-    browser.show()
+    igv_notebook.file_reader.get_ipython = get_ipython  # Workaround for a bug in igv_notebook
+    igv_notebook.init()
+    browser = igv_notebook.Browser({"genome": genome, "locus": locus})
 
     # Ensure tracks and indices are represented as lists
-    if tracks is None: tracks = []
-    if indices is None: indices = []
+    if not tracks: tracks = []
+    if not indices: indices = []
     if type(tracks) == str: tracks = [tracks]
     if type(indices) == str: indices = [indices]
 
